@@ -1,6 +1,6 @@
 package Catmandu::AlephX::Op::BorAuth;
 use Catmandu::Sane;
-use Data::Util qw(:check :validate);
+use Catmandu::Util qw(:check :is);
 use Moo;
 
 with('Catmandu::AlephX::Response');
@@ -9,7 +9,7 @@ has z303 => (
   is => 'ro',
   lazy => 1,
   isa => sub{
-    hash_ref($_[0]);
+    check_hash_ref($_[0]);
   },
   default => sub {
     {};
@@ -19,7 +19,7 @@ has z304 => (
   is => 'ro',
   lazy => 1,
   isa => sub{
-    hash_ref($_[0]);
+    check_hash_ref($_[0]);
   },
   default => sub {
     {};
@@ -29,7 +29,7 @@ has z305 => (
   is => 'ro',
   lazy => 1,
   isa => sub{
-    hash_ref($_[0]);
+    check_hash_ref($_[0]);
   },
   default => sub {
     {};
@@ -41,20 +41,22 @@ sub op { 'bor-auth' }
 sub parse {
   my($class,$str_ref) = @_;
   my $xpath = xpath($str_ref);
+  my $op = op();
 
   my @keys = qw(z303 z304 z305);
   my %args = ();
 
   for my $key(@keys){
-    my($l) = $xpath->find("/bor-auth/$key")->get_nodelist();
+    my($l) = $xpath->find("/$op/$key")->get_nodelist();
     my $data = $l ? get_children($l,1) : {};
     $args{$key} = $data;    
   }  
 
   __PACKAGE__->new(
     %args,
-    session_id => $xpath->findvalue('/bor-auth/session-id'),
-    error => $xpath->findvalue('/bor-auth/error')
+    session_id => $xpath->findvalue("/$op/session-id"),
+    errors => $class->parse_errors($xpath),
+    content_ref => $str_ref
   ); 
 
 }
